| Title: | Comprehensive Analysis of Latent Means |
|---|---|
| Description: | Provides a Shiny application to conduct comprehensive analysis of latent means including the examination of group equivalency, propensity score analysis, measurement invariance analysis, and assessment of latent mean differences of equivalent groups with invariant data. Group equivalency and propensity score analyses are implemented using the 'MatchIt' package [Ho et al. (2011) <doi:10.18637/jss.v042.i08>], ensuring robust control for covariates. Structural equation modeling and invariance testing rely heavily on the 'lavaan' package [Rosseel (2012) <doi:10.18637/jss.v048.i02>], providing a flexible and powerful modeling framework. The application also integrates modified functions from Hammack-Brown et al. (2021) <doi:10.1002/hrdq.21452> to support factor ratio testing and the list-and-delete procedure. |
| Authors: | Kim Nimon [aut, cre], Julia Fulmore [aut] |
| Maintainer: | Kim Nimon <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0-3 |
| Built: | 2026-06-05 06:47:35 UTC |
| Source: | https://github.com/cran/calms |
run_calms() loads interactive user interface built using R shiny.
run_calms()run_calms()
Start calms
The interactive user interface is to provide an easy way for people who are not comfortable with the R command line system. Includes example data for demonstration.
Nothing
if (interactive()){ run_calms() }if (interactive()){ run_calms() }
Meta file for CALMs Demonstration Dataset
WosDemoMetaWosDemoMeta
A data frame with 11 rows and 6 variables:
Original item name in dataset
Item name to be used in CALMs
Data type: item, cov, group
Scale associated with item
Name of dataset
Numeric value denoting how missing values are coded
Meta file for CALMs demonstration dataset (ISSP Resarch Group, 2017)
data(WosDemoMeta) head(WosDemoMeta)data(WosDemoMeta) head(WosDemoMeta)